@@ -1,5 +1,6 @@
+# MIT License
 #
-# Copyright (c) 2001 - 2019 The SCons Foundation
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -19,73 +20,65 @@
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
 
-"""SCons.Errors
+"""SCons exception classes.
 
-This file contains the exception classes used to handle internal
-and user errors in SCons.
+Used to handle internal and user errors in SCons.
 
 """
 
-__revision__ = "/src/script/src/engine/SCons/Errors.py none 2019-12-16 19:06:27 none"
-
 import shutil
 import SCons.Util
 
 
 class BuildError(Exception):
-    """ Errors occurring while building.
+    """SCons Errors that can occur while building.
 
-    BuildError have the following attributes:
-    =========================================
+    Attributes:
+      Information about the cause of the build error :
 
-    Information about the cause of the build error:
-    -----------------------------------------------
+      errstr: a description of the error message
 
-    errstr : a description of the error message
+      status: the return code of the action that caused the build error.
+        Must be set to a non-zero value even if the build error is not due
+        to an action returning a non-zero returned code.
 
-    status : the return code of the action that caused the build error.
-    Must be set to a non-zero value even if the build error is not due
-    to an action returning a non-zero returned code.
+      exitstatus: SCons exit status due to this build error.
+        Must be nonzero unless due to an explicit Exit()
+        call.  Not always the same as status, since
+        actions return a status code that should be
+        respected, but SCons typically exits with 2
+        irrespective of the return value of the failed
+        action.
 
-    exitstatus : SCons exit status due to this build error.
-    Must be nonzero unless due to an explicit Exit()
-    call.  Not always the same as status, since
-    actions return a status code that should be
-    respected, but SCons typically exits with 2
-    irrespective of the return value of the failed
-    action.
+      filename: The name of the file or directory that caused the
+        build error. Set to None if no files are associated with
+        this error. This might be different from the target
+        being built. For example, failure to create the
+        directory in which the target file will appear. It
+        can be None if the error is not due to a particular
+        filename.
 
-    filename : The name of the file or directory that caused the
-    build error. Set to None if no files are associated with
-    this error. This might be different from the target
-    being built. For example, failure to create the
-    directory in which the target file will appear. It
-    can be None if the error is not due to a particular
-    filename.
+      exc_info: Info about exception that caused the build
+        error. Set to (None, None, None) if this build
+        error is not due to an exception.
 
-    exc_info : Info about exception that caused the build
-    error. Set to (None, None, None) if this build
-    error is not due to an exception.
+      Information about the what caused the build error :
 
+      node: the error occurred while building this target node(s)
 
-    Information about the cause of the location of the error:
-    ---------------------------------------------------------
+      executor: the executor that caused the build to fail (might
+        be None if the build failures is not due to the
+        executor failing)
 
-    node : the error occured while building this target node(s)
+      action: the action that caused the build to fail (might be
+        None if the build failures is not due to the an
+        action failure)
 
-    executor : the executor that caused the build to fail (might
-               be None if the build failures is not due to the
-               executor failing)
+      command: the command line for the action that caused the
+        build to fail (might be None if the build failures
+        is not due to the an action failure)
 
-    action : the action that caused the build to fail (might be
-             None if the build failures is not due to the an
-             action failure)
-
-    command : the command line for the action that caused the
-              build to fail (might be None if the build failures
-              is not due to the an action failure)
     """
 
     def __init__(self,
@@ -106,8 +99,8 @@ class BuildError(Exception):
         self.action = action
         self.command = command
 
-        Exception.__init__(self, node, errstr, status, exitstatus, filename,
-                           executor, action, command, exc_info)
+        super().__init__(node, errstr, status, exitstatus, filename,
+                         executor, action, command, exc_info)
 
     def __str__(self):
         if self.filename:
@@ -135,17 +128,18 @@ class ExplicitExit(Exception):
         self.node = node
         self.status = status
         self.exitstatus = status
-        Exception.__init__(self, *args)
+        super().__init__(*args)
 
 def convert_to_BuildError(status, exc_info=None):
-    """
-    Convert any return code a BuildError Exception.
+    """Convert a return code to a BuildError Exception.
 
-    :Parameters:
-      - `status`: can either be a return code or an Exception.
-
-    The buildError.status we set here will normally be
+    The `buildError.status` we set here will normally be
     used as the exit status of the "scons" process.
+
+    Args:
+      status: can either be a return code or an Exception.
+      exc_info (tuple, optional): explicit exception information.
+
     """
 
     if not exc_info and isinstance(status, Exception):
